# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['ExternalNonContainerDatabaseOperationsInsightsManagementArgs', 'ExternalNonContainerDatabaseOperationsInsightsManagement']

@pulumi.input_type
class ExternalNonContainerDatabaseOperationsInsightsManagementArgs:
    def __init__(__self__, *,
                 enable_operations_insights: pulumi.Input[bool],
                 external_database_connector_id: pulumi.Input[str],
                 external_non_container_database_id: pulumi.Input[str]):
        """
        The set of arguments for constructing a ExternalNonContainerDatabaseOperationsInsightsManagement resource.
        :param pulumi.Input[bool] enable_operations_insights: (Updatable) Enabling OPSI on External non-container Databases . Requires boolean value "true" or "false".
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[str] external_database_connector_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the [external database connector](https://docs.cloud.oracle.com/iaas/api/#/en/database/latest/datatypes/CreateExternalDatabaseConnectorDetails).
        :param pulumi.Input[str] external_non_container_database_id: The external non-container database [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        """
        pulumi.set(__self__, "enable_operations_insights", enable_operations_insights)
        pulumi.set(__self__, "external_database_connector_id", external_database_connector_id)
        pulumi.set(__self__, "external_non_container_database_id", external_non_container_database_id)

    @property
    @pulumi.getter(name="enableOperationsInsights")
    def enable_operations_insights(self) -> pulumi.Input[bool]:
        """
        (Updatable) Enabling OPSI on External non-container Databases . Requires boolean value "true" or "false".

        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "enable_operations_insights")

    @enable_operations_insights.setter
    def enable_operations_insights(self, value: pulumi.Input[bool]):
        pulumi.set(self, "enable_operations_insights", value)

    @property
    @pulumi.getter(name="externalDatabaseConnectorId")
    def external_database_connector_id(self) -> pulumi.Input[str]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the [external database connector](https://docs.cloud.oracle.com/iaas/api/#/en/database/latest/datatypes/CreateExternalDatabaseConnectorDetails).
        """
        return pulumi.get(self, "external_database_connector_id")

    @external_database_connector_id.setter
    def external_database_connector_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "external_database_connector_id", value)

    @property
    @pulumi.getter(name="externalNonContainerDatabaseId")
    def external_non_container_database_id(self) -> pulumi.Input[str]:
        """
        The external non-container database [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        """
        return pulumi.get(self, "external_non_container_database_id")

    @external_non_container_database_id.setter
    def external_non_container_database_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "external_non_container_database_id", value)


@pulumi.input_type
class _ExternalNonContainerDatabaseOperationsInsightsManagementState:
    def __init__(__self__, *,
                 enable_operations_insights: Optional[pulumi.Input[bool]] = None,
                 external_database_connector_id: Optional[pulumi.Input[str]] = None,
                 external_non_container_database_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ExternalNonContainerDatabaseOperationsInsightsManagement resources.
        :param pulumi.Input[bool] enable_operations_insights: (Updatable) Enabling OPSI on External non-container Databases . Requires boolean value "true" or "false".
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[str] external_database_connector_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the [external database connector](https://docs.cloud.oracle.com/iaas/api/#/en/database/latest/datatypes/CreateExternalDatabaseConnectorDetails).
        :param pulumi.Input[str] external_non_container_database_id: The external non-container database [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        """
        if enable_operations_insights is not None:
            pulumi.set(__self__, "enable_operations_insights", enable_operations_insights)
        if external_database_connector_id is not None:
            pulumi.set(__self__, "external_database_connector_id", external_database_connector_id)
        if external_non_container_database_id is not None:
            pulumi.set(__self__, "external_non_container_database_id", external_non_container_database_id)

    @property
    @pulumi.getter(name="enableOperationsInsights")
    def enable_operations_insights(self) -> Optional[pulumi.Input[bool]]:
        """
        (Updatable) Enabling OPSI on External non-container Databases . Requires boolean value "true" or "false".

        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "enable_operations_insights")

    @enable_operations_insights.setter
    def enable_operations_insights(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enable_operations_insights", value)

    @property
    @pulumi.getter(name="externalDatabaseConnectorId")
    def external_database_connector_id(self) -> Optional[pulumi.Input[str]]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the [external database connector](https://docs.cloud.oracle.com/iaas/api/#/en/database/latest/datatypes/CreateExternalDatabaseConnectorDetails).
        """
        return pulumi.get(self, "external_database_connector_id")

    @external_database_connector_id.setter
    def external_database_connector_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_database_connector_id", value)

    @property
    @pulumi.getter(name="externalNonContainerDatabaseId")
    def external_non_container_database_id(self) -> Optional[pulumi.Input[str]]:
        """
        The external non-container database [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        """
        return pulumi.get(self, "external_non_container_database_id")

    @external_non_container_database_id.setter
    def external_non_container_database_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_non_container_database_id", value)


class ExternalNonContainerDatabaseOperationsInsightsManagement(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 enable_operations_insights: Optional[pulumi.Input[bool]] = None,
                 external_database_connector_id: Optional[pulumi.Input[str]] = None,
                 external_non_container_database_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        This resource provides the External Non Container Database Operations Insights Management resource in Oracle Cloud Infrastructure Database service.

        Enable Operations Insights for the external non-container database.
        When deleting this resource block , we call disable if it was in enabled state .

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_external_non_container_database_operations_insights_management = oci.database.ExternalNonContainerDatabaseOperationsInsightsManagement("testExternalNonContainerDatabaseOperationsInsightsManagement",
            external_database_connector_id=oci_database_external_database_connector["test_external_database_connector"]["id"],
            external_non_container_database_id=oci_database_external_non_container_database["test_external_non_container_database"]["id"],
            enable_operations_insights=True)
        ```

        ## Import

        Import is not supported for this resource.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] enable_operations_insights: (Updatable) Enabling OPSI on External non-container Databases . Requires boolean value "true" or "false".
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[str] external_database_connector_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the [external database connector](https://docs.cloud.oracle.com/iaas/api/#/en/database/latest/datatypes/CreateExternalDatabaseConnectorDetails).
        :param pulumi.Input[str] external_non_container_database_id: The external non-container database [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ExternalNonContainerDatabaseOperationsInsightsManagementArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides the External Non Container Database Operations Insights Management resource in Oracle Cloud Infrastructure Database service.

        Enable Operations Insights for the external non-container database.
        When deleting this resource block , we call disable if it was in enabled state .

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_external_non_container_database_operations_insights_management = oci.database.ExternalNonContainerDatabaseOperationsInsightsManagement("testExternalNonContainerDatabaseOperationsInsightsManagement",
            external_database_connector_id=oci_database_external_database_connector["test_external_database_connector"]["id"],
            external_non_container_database_id=oci_database_external_non_container_database["test_external_non_container_database"]["id"],
            enable_operations_insights=True)
        ```

        ## Import

        Import is not supported for this resource.

        :param str resource_name: The name of the resource.
        :param ExternalNonContainerDatabaseOperationsInsightsManagementArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ExternalNonContainerDatabaseOperationsInsightsManagementArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 enable_operations_insights: Optional[pulumi.Input[bool]] = None,
                 external_database_connector_id: Optional[pulumi.Input[str]] = None,
                 external_non_container_database_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ExternalNonContainerDatabaseOperationsInsightsManagementArgs.__new__(ExternalNonContainerDatabaseOperationsInsightsManagementArgs)

            if enable_operations_insights is None and not opts.urn:
                raise TypeError("Missing required property 'enable_operations_insights'")
            __props__.__dict__["enable_operations_insights"] = enable_operations_insights
            if external_database_connector_id is None and not opts.urn:
                raise TypeError("Missing required property 'external_database_connector_id'")
            __props__.__dict__["external_database_connector_id"] = external_database_connector_id
            if external_non_container_database_id is None and not opts.urn:
                raise TypeError("Missing required property 'external_non_container_database_id'")
            __props__.__dict__["external_non_container_database_id"] = external_non_container_database_id
        super(ExternalNonContainerDatabaseOperationsInsightsManagement, __self__).__init__(
            'oci:Database/externalNonContainerDatabaseOperationsInsightsManagement:ExternalNonContainerDatabaseOperationsInsightsManagement',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            enable_operations_insights: Optional[pulumi.Input[bool]] = None,
            external_database_connector_id: Optional[pulumi.Input[str]] = None,
            external_non_container_database_id: Optional[pulumi.Input[str]] = None) -> 'ExternalNonContainerDatabaseOperationsInsightsManagement':
        """
        Get an existing ExternalNonContainerDatabaseOperationsInsightsManagement resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] enable_operations_insights: (Updatable) Enabling OPSI on External non-container Databases . Requires boolean value "true" or "false".
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[str] external_database_connector_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the [external database connector](https://docs.cloud.oracle.com/iaas/api/#/en/database/latest/datatypes/CreateExternalDatabaseConnectorDetails).
        :param pulumi.Input[str] external_non_container_database_id: The external non-container database [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ExternalNonContainerDatabaseOperationsInsightsManagementState.__new__(_ExternalNonContainerDatabaseOperationsInsightsManagementState)

        __props__.__dict__["enable_operations_insights"] = enable_operations_insights
        __props__.__dict__["external_database_connector_id"] = external_database_connector_id
        __props__.__dict__["external_non_container_database_id"] = external_non_container_database_id
        return ExternalNonContainerDatabaseOperationsInsightsManagement(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="enableOperationsInsights")
    def enable_operations_insights(self) -> pulumi.Output[bool]:
        """
        (Updatable) Enabling OPSI on External non-container Databases . Requires boolean value "true" or "false".

        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "enable_operations_insights")

    @property
    @pulumi.getter(name="externalDatabaseConnectorId")
    def external_database_connector_id(self) -> pulumi.Output[str]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the [external database connector](https://docs.cloud.oracle.com/iaas/api/#/en/database/latest/datatypes/CreateExternalDatabaseConnectorDetails).
        """
        return pulumi.get(self, "external_database_connector_id")

    @property
    @pulumi.getter(name="externalNonContainerDatabaseId")
    def external_non_container_database_id(self) -> pulumi.Output[str]:
        """
        The external non-container database [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        """
        return pulumi.get(self, "external_non_container_database_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetHostScanRecipeResult',
    'AwaitableGetHostScanRecipeResult',
    'get_host_scan_recipe',
    'get_host_scan_recipe_output',
]

@pulumi.output_type
class GetHostScanRecipeResult:
    """
    A collection of values returned by getHostScanRecipe.
    """
    def __init__(__self__, agent_settings=None, application_settings=None, compartment_id=None, defined_tags=None, display_name=None, freeform_tags=None, host_scan_recipe_id=None, id=None, port_settings=None, schedules=None, state=None, system_tags=None, time_created=None, time_updated=None):
        if agent_settings and not isinstance(agent_settings, list):
            raise TypeError("Expected argument 'agent_settings' to be a list")
        pulumi.set(__self__, "agent_settings", agent_settings)
        if application_settings and not isinstance(application_settings, list):
            raise TypeError("Expected argument 'application_settings' to be a list")
        pulumi.set(__self__, "application_settings", application_settings)
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if defined_tags and not isinstance(defined_tags, dict):
            raise TypeError("Expected argument 'defined_tags' to be a dict")
        pulumi.set(__self__, "defined_tags", defined_tags)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if freeform_tags and not isinstance(freeform_tags, dict):
            raise TypeError("Expected argument 'freeform_tags' to be a dict")
        pulumi.set(__self__, "freeform_tags", freeform_tags)
        if host_scan_recipe_id and not isinstance(host_scan_recipe_id, str):
            raise TypeError("Expected argument 'host_scan_recipe_id' to be a str")
        pulumi.set(__self__, "host_scan_recipe_id", host_scan_recipe_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if port_settings and not isinstance(port_settings, list):
            raise TypeError("Expected argument 'port_settings' to be a list")
        pulumi.set(__self__, "port_settings", port_settings)
        if schedules and not isinstance(schedules, list):
            raise TypeError("Expected argument 'schedules' to be a list")
        pulumi.set(__self__, "schedules", schedules)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if system_tags and not isinstance(system_tags, dict):
            raise TypeError("Expected argument 'system_tags' to be a dict")
        pulumi.set(__self__, "system_tags", system_tags)
        if time_created and not isinstance(time_created, str):
            raise TypeError("Expected argument 'time_created' to be a str")
        pulumi.set(__self__, "time_created", time_created)
        if time_updated and not isinstance(time_updated, str):
            raise TypeError("Expected argument 'time_updated' to be a str")
        pulumi.set(__self__, "time_updated", time_updated)

    @property
    @pulumi.getter(name="agentSettings")
    def agent_settings(self) -> Sequence['outputs.GetHostScanRecipeAgentSettingResult']:
        """
        Agent scan settings for a host scan
        """
        return pulumi.get(self, "agent_settings")

    @property
    @pulumi.getter(name="applicationSettings")
    def application_settings(self) -> Sequence['outputs.GetHostScanRecipeApplicationSettingResult']:
        """
        Agent scan settings for an application scan (as a part of a host scan)
        """
        return pulumi.get(self, "application_settings")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        Compartment ID of the scan recipe
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Mapping[str, Any]:
        """
        Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        Recipe identifier, which can be renamed
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Mapping[str, Any]:
        """
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter(name="hostScanRecipeId")
    def host_scan_recipe_id(self) -> str:
        return pulumi.get(self, "host_scan_recipe_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        Unique identifier of the config that is immutable on creation
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="portSettings")
    def port_settings(self) -> Sequence['outputs.GetHostScanRecipePortSettingResult']:
        """
        Port scan settings for a host scan
        """
        return pulumi.get(self, "port_settings")

    @property
    @pulumi.getter
    def schedules(self) -> Sequence['outputs.GetHostScanRecipeScheduleResult']:
        """
        A scanning schedule
        """
        return pulumi.get(self, "schedules")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        The current state of the config.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="systemTags")
    def system_tags(self) -> Mapping[str, Any]:
        """
        Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"orcl-cloud.free-tier-retained": "true"}`
        """
        return pulumi.get(self, "system_tags")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        Date and time the recipe was created, format as described in [RFC 3339](https://tools.ietf.org/rfc/rfc3339)
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> str:
        """
        Date and time the recipe was last updated, format as described in [RFC 3339](https://tools.ietf.org/rfc/rfc3339)
        """
        return pulumi.get(self, "time_updated")


class AwaitableGetHostScanRecipeResult(GetHostScanRecipeResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetHostScanRecipeResult(
            agent_settings=self.agent_settings,
            application_settings=self.application_settings,
            compartment_id=self.compartment_id,
            defined_tags=self.defined_tags,
            display_name=self.display_name,
            freeform_tags=self.freeform_tags,
            host_scan_recipe_id=self.host_scan_recipe_id,
            id=self.id,
            port_settings=self.port_settings,
            schedules=self.schedules,
            state=self.state,
            system_tags=self.system_tags,
            time_created=self.time_created,
            time_updated=self.time_updated)


def get_host_scan_recipe(host_scan_recipe_id: Optional[str] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetHostScanRecipeResult:
    """
    This data source provides details about a specific Host Scan Recipe resource in Oracle Cloud Infrastructure Vulnerability Scanning service.

    Retrieves a HostScanRecipe identified by the recipe ID. A recipe determines the types of security issues that you want scanned, and how often to scan.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_host_scan_recipe = oci.VulnerabilityScanning.get_host_scan_recipe(host_scan_recipe_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str host_scan_recipe_id: unique HostScanRecipe identifier
    """
    __args__ = dict()
    __args__['hostScanRecipeId'] = host_scan_recipe_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:VulnerabilityScanning/getHostScanRecipe:getHostScanRecipe', __args__, opts=opts, typ=GetHostScanRecipeResult).value

    return AwaitableGetHostScanRecipeResult(
        agent_settings=__ret__.agent_settings,
        application_settings=__ret__.application_settings,
        compartment_id=__ret__.compartment_id,
        defined_tags=__ret__.defined_tags,
        display_name=__ret__.display_name,
        freeform_tags=__ret__.freeform_tags,
        host_scan_recipe_id=__ret__.host_scan_recipe_id,
        id=__ret__.id,
        port_settings=__ret__.port_settings,
        schedules=__ret__.schedules,
        state=__ret__.state,
        system_tags=__ret__.system_tags,
        time_created=__ret__.time_created,
        time_updated=__ret__.time_updated)


@_utilities.lift_output_func(get_host_scan_recipe)
def get_host_scan_recipe_output(host_scan_recipe_id: Optional[pulumi.Input[str]] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetHostScanRecipeResult]:
    """
    This data source provides details about a specific Host Scan Recipe resource in Oracle Cloud Infrastructure Vulnerability Scanning service.

    Retrieves a HostScanRecipe identified by the recipe ID. A recipe determines the types of security issues that you want scanned, and how often to scan.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_host_scan_recipe = oci.VulnerabilityScanning.get_host_scan_recipe(host_scan_recipe_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str host_scan_recipe_id: unique HostScanRecipe identifier
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetRrsetsResult',
    'AwaitableGetRrsetsResult',
    'get_rrsets',
    'get_rrsets_output',
]

@pulumi.output_type
class GetRrsetsResult:
    """
    A collection of values returned by getRrsets.
    """
    def __init__(__self__, domain=None, domain_contains=None, filters=None, id=None, rrsets=None, rtype=None, scope=None, view_id=None, zone_name_or_id=None):
        if domain and not isinstance(domain, str):
            raise TypeError("Expected argument 'domain' to be a str")
        pulumi.set(__self__, "domain", domain)
        if domain_contains and not isinstance(domain_contains, str):
            raise TypeError("Expected argument 'domain_contains' to be a str")
        pulumi.set(__self__, "domain_contains", domain_contains)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if rrsets and not isinstance(rrsets, list):
            raise TypeError("Expected argument 'rrsets' to be a list")
        pulumi.set(__self__, "rrsets", rrsets)
        if rtype and not isinstance(rtype, str):
            raise TypeError("Expected argument 'rtype' to be a str")
        pulumi.set(__self__, "rtype", rtype)
        if scope and not isinstance(scope, str):
            raise TypeError("Expected argument 'scope' to be a str")
        pulumi.set(__self__, "scope", scope)
        if view_id and not isinstance(view_id, str):
            raise TypeError("Expected argument 'view_id' to be a str")
        pulumi.set(__self__, "view_id", view_id)
        if zone_name_or_id and not isinstance(zone_name_or_id, str):
            raise TypeError("Expected argument 'zone_name_or_id' to be a str")
        pulumi.set(__self__, "zone_name_or_id", zone_name_or_id)

    @property
    @pulumi.getter
    def domain(self) -> Optional[str]:
        """
        The fully qualified domain name where the record can be located.
        """
        return pulumi.get(self, "domain")

    @property
    @pulumi.getter(name="domainContains")
    def domain_contains(self) -> Optional[str]:
        return pulumi.get(self, "domain_contains")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetRrsetsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def rrsets(self) -> Sequence['outputs.GetRrsetsRrsetResult']:
        """
        The list of rrsets.
        """
        return pulumi.get(self, "rrsets")

    @property
    @pulumi.getter
    def rtype(self) -> Optional[str]:
        """
        The type of DNS record, such as A or CNAME. For more information, see [Resource Record (RR) TYPEs](https://www.iana.org/assignments/dns-parameters/dns-parameters.xhtml#dns-parameters-4).
        """
        return pulumi.get(self, "rtype")

    @property
    @pulumi.getter
    def scope(self) -> Optional[str]:
        return pulumi.get(self, "scope")

    @property
    @pulumi.getter(name="viewId")
    def view_id(self) -> Optional[str]:
        return pulumi.get(self, "view_id")

    @property
    @pulumi.getter(name="zoneNameOrId")
    def zone_name_or_id(self) -> str:
        return pulumi.get(self, "zone_name_or_id")


class AwaitableGetRrsetsResult(GetRrsetsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRrsetsResult(
            domain=self.domain,
            domain_contains=self.domain_contains,
            filters=self.filters,
            id=self.id,
            rrsets=self.rrsets,
            rtype=self.rtype,
            scope=self.scope,
            view_id=self.view_id,
            zone_name_or_id=self.zone_name_or_id)


def get_rrsets(domain: Optional[str] = None,
               domain_contains: Optional[str] = None,
               filters: Optional[Sequence[pulumi.InputType['GetRrsetsFilterArgs']]] = None,
               rtype: Optional[str] = None,
               scope: Optional[str] = None,
               view_id: Optional[str] = None,
               zone_name_or_id: Optional[str] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRrsetsResult:
    """
    This data source provides the list of RRsets in Oracle Cloud Infrastructure DNS service.

    Gets a list of all rrsets in the specified zone. You can optionally filter the results using the listed parameters.
    For private zones, the scope query parameter is required with a value of `PRIVATE`. When the zone name is
    provided as a path parameter and `PRIVATE` is used for the scope query parameter then the viewId query
    parameter is required.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_rrsets = oci.Dns.get_rrsets(zone_name_or_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        domain=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        domain_contains=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        rtype=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        scope=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        view_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str domain: The target fully-qualified domain name (FQDN) within the target zone.
    :param str domain_contains: Matches any rrset whose fully-qualified domain name (FQDN) contains the provided value.
    :param str rtype: Search by record type. Will match any record whose [type](https://www.iana.org/assignments/dns-parameters/dns-parameters.xhtml#dns-parameters-4) (case-insensitive) equals the provided value.
    :param str scope: Specifies to operate only on resources that have a matching DNS scope.
    :param str view_id: The OCID of the view the resource is associated with.
    :param str zone_name_or_id: The name or OCID of the target zone.
    """
    __args__ = dict()
    __args__['domain'] = domain
    __args__['domainContains'] = domain_contains
    __args__['filters'] = filters
    __args__['rtype'] = rtype
    __args__['scope'] = scope
    __args__['viewId'] = view_id
    __args__['zoneNameOrId'] = zone_name_or_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Dns/getRrsets:getRrsets', __args__, opts=opts, typ=GetRrsetsResult).value

    return AwaitableGetRrsetsResult(
        domain=__ret__.domain,
        domain_contains=__ret__.domain_contains,
        filters=__ret__.filters,
        id=__ret__.id,
        rrsets=__ret__.rrsets,
        rtype=__ret__.rtype,
        scope=__ret__.scope,
        view_id=__ret__.view_id,
        zone_name_or_id=__ret__.zone_name_or_id)


@_utilities.lift_output_func(get_rrsets)
def get_rrsets_output(domain: Optional[pulumi.Input[Optional[str]]] = None,
                      domain_contains: Optional[pulumi.Input[Optional[str]]] = None,
                      filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetRrsetsFilterArgs']]]]] = None,
                      rtype: Optional[pulumi.Input[Optional[str]]] = None,
                      scope: Optional[pulumi.Input[Optional[str]]] = None,
                      view_id: Optional[pulumi.Input[Optional[str]]] = None,
                      zone_name_or_id: Optional[pulumi.Input[str]] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetRrsetsResult]:
    """
    This data source provides the list of RRsets in Oracle Cloud Infrastructure DNS service.

    Gets a list of all rrsets in the specified zone. You can optionally filter the results using the listed parameters.
    For private zones, the scope query parameter is required with a value of `PRIVATE`. When the zone name is
    provided as a path parameter and `PRIVATE` is used for the scope query parameter then the viewId query
    parameter is required.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_rrsets = oci.Dns.get_rrsets(zone_name_or_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        domain=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        domain_contains=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        rtype=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        scope=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        view_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str domain: The target fully-qualified domain name (FQDN) within the target zone.
    :param str domain_contains: Matches any rrset whose fully-qualified domain name (FQDN) contains the provided value.
    :param str rtype: Search by record type. Will match any record whose [type](https://www.iana.org/assignments/dns-parameters/dns-parameters.xhtml#dns-parameters-4) (case-insensitive) equals the provided value.
    :param str scope: Specifies to operate only on resources that have a matching DNS scope.
    :param str view_id: The OCID of the view the resource is associated with.
    :param str zone_name_or_id: The name or OCID of the target zone.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetSecretsResult',
    'AwaitableGetSecretsResult',
    'get_secrets',
    'get_secrets_output',
]

@pulumi.output_type
class GetSecretsResult:
    """
    A collection of values returned by getSecrets.
    """
    def __init__(__self__, compartment_id=None, filters=None, id=None, name=None, secrets=None, state=None, vault_id=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if secrets and not isinstance(secrets, list):
            raise TypeError("Expected argument 'secrets' to be a list")
        pulumi.set(__self__, "secrets", secrets)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if vault_id and not isinstance(vault_id, str):
            raise TypeError("Expected argument 'vault_id' to be a str")
        pulumi.set(__self__, "vault_id", vault_id)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The OCID of the compartment where you want to create the secret.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetSecretsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def secrets(self) -> Sequence['outputs.GetSecretsSecretResult']:
        """
        The list of secrets.
        """
        return pulumi.get(self, "secrets")

    @property
    @pulumi.getter
    def state(self) -> Optional[str]:
        """
        The current lifecycle state of the secret.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="vaultId")
    def vault_id(self) -> Optional[str]:
        """
        The OCID of the Vault in which the secret exists
        """
        return pulumi.get(self, "vault_id")


class AwaitableGetSecretsResult(GetSecretsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSecretsResult(
            compartment_id=self.compartment_id,
            filters=self.filters,
            id=self.id,
            name=self.name,
            secrets=self.secrets,
            state=self.state,
            vault_id=self.vault_id)


def get_secrets(compartment_id: Optional[str] = None,
                filters: Optional[Sequence[pulumi.InputType['GetSecretsFilterArgs']]] = None,
                name: Optional[str] = None,
                state: Optional[str] = None,
                vault_id: Optional[str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSecretsResult:
    """
    This data source provides the list of Secrets in Oracle Cloud Infrastructure Vault service.

    Lists all secrets in the specified vault and compartment.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_secrets = oci.Vault.get_secrets(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        vault_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The OCID of the compartment.
    :param str name: The secret name.
    :param str state: A filter that returns only resources that match the specified lifecycle state. The state value is case-insensitive.
    :param str vault_id: The OCID of the vault.
    """
    __args__ = dict()
    __args__['compartmentId'] = compartment_id
    __args__['filters'] = filters
    __args__['name'] = name
    __args__['state'] = state
    __args__['vaultId'] = vault_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Vault/getSecrets:getSecrets', __args__, opts=opts, typ=GetSecretsResult).value

    return AwaitableGetSecretsResult(
        compartment_id=__ret__.compartment_id,
        filters=__ret__.filters,
        id=__ret__.id,
        name=__ret__.name,
        secrets=__ret__.secrets,
        state=__ret__.state,
        vault_id=__ret__.vault_id)


@_utilities.lift_output_func(get_secrets)
def get_secrets_output(compartment_id: Optional[pulumi.Input[str]] = None,
                       filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetSecretsFilterArgs']]]]] = None,
                       name: Optional[pulumi.Input[Optional[str]]] = None,
                       state: Optional[pulumi.Input[Optional[str]]] = None,
                       vault_id: Optional[pulumi.Input[Optional[str]]] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetSecretsResult]:
    """
    This data source provides the list of Secrets in Oracle Cloud Infrastructure Vault service.

    Lists all secrets in the specified vault and compartment.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_secrets = oci.Vault.get_secrets(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        vault_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The OCID of the compartment.
    :param str name: The secret name.
    :param str state: A filter that returns only resources that match the specified lifecycle state. The state value is case-insensitive.
    :param str vault_id: The OCID of the vault.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetStreamCdnConfigsResult',
    'AwaitableGetStreamCdnConfigsResult',
    'get_stream_cdn_configs',
    'get_stream_cdn_configs_output',
]

@pulumi.output_type
class GetStreamCdnConfigsResult:
    """
    A collection of values returned by getStreamCdnConfigs.
    """
    def __init__(__self__, display_name=None, distribution_channel_id=None, filters=None, id=None, state=None, stream_cdn_config_collections=None):
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if distribution_channel_id and not isinstance(distribution_channel_id, str):
            raise TypeError("Expected argument 'distribution_channel_id' to be a str")
        pulumi.set(__self__, "distribution_channel_id", distribution_channel_id)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if stream_cdn_config_collections and not isinstance(stream_cdn_config_collections, list):
            raise TypeError("Expected argument 'stream_cdn_config_collections' to be a list")
        pulumi.set(__self__, "stream_cdn_config_collections", stream_cdn_config_collections)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[str]:
        """
        The CDN Configuration identifier or display name, which can be renamed and is not necessarily unique. Avoid entering confidential information.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="distributionChannelId")
    def distribution_channel_id(self) -> str:
        """
        Distribution Channel Identifier.
        """
        return pulumi.get(self, "distribution_channel_id")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetStreamCdnConfigsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> Optional[str]:
        """
        Unique identifier that is immutable on creation.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def state(self) -> Optional[str]:
        """
        The current state of the CDN Configuration.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="streamCdnConfigCollections")
    def stream_cdn_config_collections(self) -> Sequence['outputs.GetStreamCdnConfigsStreamCdnConfigCollectionResult']:
        """
        The list of stream_cdn_config_collection.
        """
        return pulumi.get(self, "stream_cdn_config_collections")


class AwaitableGetStreamCdnConfigsResult(GetStreamCdnConfigsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetStreamCdnConfigsResult(
            display_name=self.display_name,
            distribution_channel_id=self.distribution_channel_id,
            filters=self.filters,
            id=self.id,
            state=self.state,
            stream_cdn_config_collections=self.stream_cdn_config_collections)


def get_stream_cdn_configs(display_name: Optional[str] = None,
                           distribution_channel_id: Optional[str] = None,
                           filters: Optional[Sequence[pulumi.InputType['GetStreamCdnConfigsFilterArgs']]] = None,
                           id: Optional[str] = None,
                           state: Optional[str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetStreamCdnConfigsResult:
    """
    This data source provides the list of Stream Cdn Configs in Oracle Cloud Infrastructure Media Services service.

    Lists the StreamCdnConfig.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_stream_cdn_configs = oci.MediaServices.get_stream_cdn_configs(distribution_channel_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str display_name: A filter to return only the resources that match the entire display name given.
    :param str distribution_channel_id: The Stream Distribution Channel identifier this CdnConfig belongs to.
    :param str id: Unique StreamCdnConfig identifier.
    :param str state: A filter to return only the resources with lifecycleState matching the given lifecycleState.
    """
    __args__ = dict()
    __args__['displayName'] = display_name
    __args__['distributionChannelId'] = distribution_channel_id
    __args__['filters'] = filters
    __args__['id'] = id
    __args__['state'] = state
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:MediaServices/getStreamCdnConfigs:getStreamCdnConfigs', __args__, opts=opts, typ=GetStreamCdnConfigsResult).value

    return AwaitableGetStreamCdnConfigsResult(
        display_name=__ret__.display_name,
        distribution_channel_id=__ret__.distribution_channel_id,
        filters=__ret__.filters,
        id=__ret__.id,
        state=__ret__.state,
        stream_cdn_config_collections=__ret__.stream_cdn_config_collections)


@_utilities.lift_output_func(get_stream_cdn_configs)
def get_stream_cdn_configs_output(display_name: Optional[pulumi.Input[Optional[str]]] = None,
                                  distribution_channel_id: Optional[pulumi.Input[str]] = None,
                                  filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetStreamCdnConfigsFilterArgs']]]]] = None,
                                  id: Optional[pulumi.Input[Optional[str]]] = None,
                                  state: Optional[pulumi.Input[Optional[str]]] = None,
                                  opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetStreamCdnConfigsResult]:
    """
    This data source provides the list of Stream Cdn Configs in Oracle Cloud Infrastructure Media Services service.

    Lists the StreamCdnConfig.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_stream_cdn_configs = oci.MediaServices.get_stream_cdn_configs(distribution_channel_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str display_name: A filter to return only the resources that match the entire display name given.
    :param str distribution_channel_id: The Stream Distribution Channel identifier this CdnConfig belongs to.
    :param str id: Unique StreamCdnConfig identifier.
    :param str state: A filter to return only the resources with lifecycleState matching the given lifecycleState.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['LogAnalyticsUnprocessedDataBucketManagementArgs', 'LogAnalyticsUnprocessedDataBucketManagement']

@pulumi.input_type
class LogAnalyticsUnprocessedDataBucketManagementArgs:
    def __init__(__self__, *,
                 bucket: pulumi.Input[str],
                 namespace: pulumi.Input[str],
                 is_enabled: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a LogAnalyticsUnprocessedDataBucketManagement resource.
        :param pulumi.Input[str] bucket: Name of the Object Storage bucket.
        :param pulumi.Input[str] namespace: The Logging Analytics namespace used for the request. 
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[bool] is_enabled: Flag that specifies if this configuration is enabled or not.
        """
        pulumi.set(__self__, "bucket", bucket)
        pulumi.set(__self__, "namespace", namespace)
        if is_enabled is not None:
            pulumi.set(__self__, "is_enabled", is_enabled)

    @property
    @pulumi.getter
    def bucket(self) -> pulumi.Input[str]:
        """
        Name of the Object Storage bucket.
        """
        return pulumi.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: pulumi.Input[str]):
        pulumi.set(self, "bucket", value)

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Input[str]:
        """
        The Logging Analytics namespace used for the request. 


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: pulumi.Input[str]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter(name="isEnabled")
    def is_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Flag that specifies if this configuration is enabled or not.
        """
        return pulumi.get(self, "is_enabled")

    @is_enabled.setter
    def is_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_enabled", value)


@pulumi.input_type
class _LogAnalyticsUnprocessedDataBucketManagementState:
    def __init__(__self__, *,
                 bucket: Optional[pulumi.Input[str]] = None,
                 is_enabled: Optional[pulumi.Input[bool]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 time_created: Optional[pulumi.Input[str]] = None,
                 time_updated: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering LogAnalyticsUnprocessedDataBucketManagement resources.
        :param pulumi.Input[str] bucket: Name of the Object Storage bucket.
        :param pulumi.Input[bool] is_enabled: Flag that specifies if this configuration is enabled or not.
        :param pulumi.Input[str] namespace: The Logging Analytics namespace used for the request. 
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[str] time_created: The time when this record is created. An RFC3339 formatted datetime string.
        :param pulumi.Input[str] time_updated: The latest time when this record is updated. An RFC3339 formatted datetime string.
        """
        if bucket is not None:
            pulumi.set(__self__, "bucket", bucket)
        if is_enabled is not None:
            pulumi.set(__self__, "is_enabled", is_enabled)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if time_created is not None:
            pulumi.set(__self__, "time_created", time_created)
        if time_updated is not None:
            pulumi.set(__self__, "time_updated", time_updated)

    @property
    @pulumi.getter
    def bucket(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the Object Storage bucket.
        """
        return pulumi.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bucket", value)

    @property
    @pulumi.getter(name="isEnabled")
    def is_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Flag that specifies if this configuration is enabled or not.
        """
        return pulumi.get(self, "is_enabled")

    @is_enabled.setter
    def is_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_enabled", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The Logging Analytics namespace used for the request. 


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> Optional[pulumi.Input[str]]:
        """
        The time when this record is created. An RFC3339 formatted datetime string.
        """
        return pulumi.get(self, "time_created")

    @time_created.setter
    def time_created(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_created", value)

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> Optional[pulumi.Input[str]]:
        """
        The latest time when this record is updated. An RFC3339 formatted datetime string.
        """
        return pulumi.get(self, "time_updated")

    @time_updated.setter
    def time_updated(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_updated", value)


class LogAnalyticsUnprocessedDataBucketManagement(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bucket: Optional[pulumi.Input[str]] = None,
                 is_enabled: Optional[pulumi.Input[bool]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        This resource provides the Log Analytics Unprocessed Data Bucket Management resource in Oracle Cloud Infrastructure Log Analytics service.

        This API configures a bucket to store unprocessed payloads.
        While processing there could be reasons a payload cannot be processed (mismatched structure, corrupted archive format, etc),
        if configured the payload would be uploaded to the bucket for verification.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_log_analytics_unprocessed_data_bucket_management = oci.log_analytics.LogAnalyticsUnprocessedDataBucketManagement("testLogAnalyticsUnprocessedDataBucketManagement",
            bucket=var["log_analytics_unprocessed_data_bucket_management_bucket"],
            namespace=var["log_analytics_unprocessed_data_bucket_management_namespace"])
        ```

        ## Import

        Import is not supported for LogAnalyticsUnprocessedDataBucketManagement

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] bucket: Name of the Object Storage bucket.
        :param pulumi.Input[bool] is_enabled: Flag that specifies if this configuration is enabled or not.
        :param pulumi.Input[str] namespace: The Logging Analytics namespace used for the request. 
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: LogAnalyticsUnprocessedDataBucketManagementArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides the Log Analytics Unprocessed Data Bucket Management resource in Oracle Cloud Infrastructure Log Analytics service.

        This API configures a bucket to store unprocessed payloads.
        While processing there could be reasons a payload cannot be processed (mismatched structure, corrupted archive format, etc),
        if configured the payload would be uploaded to the bucket for verification.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_log_analytics_unprocessed_data_bucket_management = oci.log_analytics.LogAnalyticsUnprocessedDataBucketManagement("testLogAnalyticsUnprocessedDataBucketManagement",
            bucket=var["log_analytics_unprocessed_data_bucket_management_bucket"],
            namespace=var["log_analytics_unprocessed_data_bucket_management_namespace"])
        ```

        ## Import

        Import is not supported for LogAnalyticsUnprocessedDataBucketManagement

        :param str resource_name: The name of the resource.
        :param LogAnalyticsUnprocessedDataBucketManagementArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(LogAnalyticsUnprocessedDataBucketManagementArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bucket: Optional[pulumi.Input[str]] = None,
                 is_enabled: Optional[pulumi.Input[bool]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = LogAnalyticsUnprocessedDataBucketManagementArgs.__new__(LogAnalyticsUnprocessedDataBucketManagementArgs)

            if bucket is None and not opts.urn:
                raise TypeError("Missing required property 'bucket'")
            __props__.__dict__["bucket"] = bucket
            __props__.__dict__["is_enabled"] = is_enabled
            if namespace is None and not opts.urn:
                raise TypeError("Missing required property 'namespace'")
            __props__.__dict__["namespace"] = namespace
            __props__.__dict__["time_created"] = None
            __props__.__dict__["time_updated"] = None
        super(LogAnalyticsUnprocessedDataBucketManagement, __self__).__init__(
            'oci:LogAnalytics/logAnalyticsUnprocessedDataBucketManagement:LogAnalyticsUnprocessedDataBucketManagement',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            bucket: Optional[pulumi.Input[str]] = None,
            is_enabled: Optional[pulumi.Input[bool]] = None,
            namespace: Optional[pulumi.Input[str]] = None,
            time_created: Optional[pulumi.Input[str]] = None,
            time_updated: Optional[pulumi.Input[str]] = None) -> 'LogAnalyticsUnprocessedDataBucketManagement':
        """
        Get an existing LogAnalyticsUnprocessedDataBucketManagement resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] bucket: Name of the Object Storage bucket.
        :param pulumi.Input[bool] is_enabled: Flag that specifies if this configuration is enabled or not.
        :param pulumi.Input[str] namespace: The Logging Analytics namespace used for the request. 
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[str] time_created: The time when this record is created. An RFC3339 formatted datetime string.
        :param pulumi.Input[str] time_updated: The latest time when this record is updated. An RFC3339 formatted datetime string.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _LogAnalyticsUnprocessedDataBucketManagementState.__new__(_LogAnalyticsUnprocessedDataBucketManagementState)

        __props__.__dict__["bucket"] = bucket
        __props__.__dict__["is_enabled"] = is_enabled
        __props__.__dict__["namespace"] = namespace
        __props__.__dict__["time_created"] = time_created
        __props__.__dict__["time_updated"] = time_updated
        return LogAnalyticsUnprocessedDataBucketManagement(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def bucket(self) -> pulumi.Output[str]:
        """
        Name of the Object Storage bucket.
        """
        return pulumi.get(self, "bucket")

    @property
    @pulumi.getter(name="isEnabled")
    def is_enabled(self) -> pulumi.Output[bool]:
        """
        Flag that specifies if this configuration is enabled or not.
        """
        return pulumi.get(self, "is_enabled")

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Output[str]:
        """
        The Logging Analytics namespace used for the request. 


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> pulumi.Output[str]:
        """
        The time when this record is created. An RFC3339 formatted datetime string.
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> pulumi.Output[str]:
        """
        The latest time when this record is updated. An RFC3339 formatted datetime string.
        """
        return pulumi.get(self, "time_updated")

